@@ -1,11 +1,11 @@
-from bigO import bigO
+from bigO import BigO
 
 
 def isSorted(func):
-    def wrapper(array):
-        lib = bigO()
+    def wrapper(array, *args):
+        lib = BigO()
 
-        result = func(array)
+        result = func(array, *args)
 
         _sorted, index = lib.isAscendingSorted(result)
         if index == 1:
